import argparse

from parser import DependencyParser


argument_parser = argparse.ArgumentParser(description="""
    Get information if your dependent packages are Python 3 compatible yet
""".strip())
argument_parser.add_argument('-v', '--verbose',
    help="Display information about all packages in the requirements file",
    action='store_true', default=False
)
argument_parser.add_argument('--ignore',
    help="Prefixes of packages that you\'d like to ignore while parsing the file",
    nargs='*', default=[]
)
argument_parser.add_argument('filename',
    help="Name of the file that contains the dependencies",
)

def run():
    args = argument_parser.parse_args()
    dependency_parser = DependencyParser(args.ignore, args.verbose)
    dependency_parser.parse_file(args.filename)



from evaluators import is_ok_on_pypi


class DependencyParser(object):

    def __init__(self, ignored_prefixes=None, verbose=False):
        self.ignored_prefixes = ignored_prefixes
        self.verbose = verbose

    def parse_file(self, filename):
        with open(filename, 'r') as f:
            for line in f.readlines():
                self.parse_line(line.strip())

    def parse_line(self, line):
        if not len(line) or line.startswith('#'):
            return

        if any([line.startswith(prefix) for prefix in self.ignored_prefixes]):
            return

        package_info = line.split('==')
        package_name = package_info[0]
        package_version = package_info[1] if 2 == len(package_info) else None

        pypi_looks_good = is_ok_on_pypi(package_name, package_version)
        if not pypi_looks_good or self.verbose:
            print('{indicator}-{package_name}@{package_version}'.format(
                indicator='OK' if pypi_looks_good else 'NO',
                package_name=package_name,
                package_version=package_version
            ))



import requests


def is_ok_on_pypi(package_name, package_version=None):
    response = requests.get('https://pypi.python.org/pypi/{package_name}/{package_version}'.format(
        package_name=package_name,
        package_version='' if package_version is None else package_version
    ))
    return 'Python :: 3' in response.content



from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='3debt',
    version='0.0.6',
    description='Python 3 dependency checker',
    long_description=long_description,
    url='https://github.com/akoskaaa/3debt',
    author='Akos Hochrein',
    author_email='hoch.akos@gmail.com',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
    ],
    packages=find_packages(exclude=['contrib', 'docs', 'tests', 'scripts']),
    install_requires=[
        'argparse',
        'requests'
    ],
    entry_points={
        'console_scripts': [
            '3debt=src:run',
        ],
    },
)
